// (C) 2019-2022 GoodData Corporation
import { invariant } from "ts-invariant";
import { isKpiWidgetDefinition, isKpiWidget, } from "@gooddata/sdk-model";
import { WidgetBaseBuilder } from "./widgetFactory.js";
import { resolveValueOrUpdateCallback } from "../builder.js";
/**
 * @alpha
 */
export class KpiWidgetBuilder extends WidgetBaseBuilder {
    item;
    validator;
    constructor(item, validator) {
        super(item, validator);
        this.item = item;
        this.validator = validator;
    }
    static for(kpiWidget) {
        invariant(isKpiWidgetDefinition(kpiWidget) || isKpiWidget(kpiWidget), "Provided data must be IKpiWidget or IKpiWidgetDefinition!");
        return new KpiWidgetBuilder(kpiWidget);
    }
    static forNew(measure) {
        const emptyKpiWidget = {
            description: "",
            drills: [],
            ignoreDashboardFilters: [],
            title: "",
            type: "kpi",
            kpi: {
                metric: measure,
                comparisonType: "none",
            },
        };
        return KpiWidgetBuilder.for(emptyKpiWidget);
    }
    // TODO: un-nest legacy kpi
    setKpiWidgetProp = (prop, valueOrUpdateCallback) => {
        this.setWidget((w) => ({
            ...w,
            kpi: {
                ...w.kpi,
                [prop]: resolveValueOrUpdateCallback(valueOrUpdateCallback, w.kpi[prop]),
            },
        }));
        return this;
    };
    drills = (valueOrUpdateCallback) => this.setWidgetProp("drills", valueOrUpdateCallback);
    measure = (valueOrUpdateCallback) => this.setKpiWidgetProp("metric", valueOrUpdateCallback);
    comparisonType = (valueOrUpdateCallback) => this.setKpiWidgetProp("comparisonType", valueOrUpdateCallback);
    comparisonDirection = (valueOrUpdateCallback) => this.setKpiWidgetProp("comparisonDirection", valueOrUpdateCallback);
}
/**
 * @alpha
 */
export const newKpiWidget = (measure, modifications) => {
    return KpiWidgetBuilder.forNew(measure).modify(modifications).build();
};
//# sourceMappingURL=kpiWidgetFactory.js.map